LoopPoints

Struct LoopPoints 

pub struct LoopPoints {
    pub repeat: Meas,
    pub last: Option<NonZeroMeas>,
}
Where the song ends and starts repeating from, as defined by the song.

Fields

repeat: Meas

The Meas the song starts playing from when looped.

last: Option<NonZeroMeas>

The last Meas the song plays before ending or repeating.

If None, the song will last until the last event has been played.

Implementations

Source

impl LoopPoints

pub fn from_ticks(repeat: Tick, last: Tick, timing: Timing) -> Self

Convert Ticks into Meas loop points.