pub struct LoopPoints {
pub repeat: Meas,
pub last: Option<NonZeroMeas>,
}Expand description
Where the song ends and starts repeating from, as defined by the song.
Fields
repeat: MeasThe Meas the song starts playing from when looped.
last: Option<NonZeroMeas>The last Meas the song plays before ending or repeating.
If None, the song will last until the last event has been played.
Implementations
Sourceimpl LoopPoints
impl LoopPoints